@@ -22,35 +22,50 @@ how_to_slide = ('''# Creating Slides
     - `%%slide integer` on cell top auto picks slide and `%%title` auto picks title page.
     - `%%slide integer -m` can be used to create slide from full markdown (extended one).
     - You can use context managers like `with ls.slide(): ...` and `with ls.title(): ...` in place of `%%slide` and `%%title` respectively.
+
 ```python
-#------------ Cell 1 --------------------
 import ipyslides as isd 
-ls = isd.LiveSlides(**settings_kwargs)
+ls = isd.LiveSlides()
 ls.settings.set_animation('zoom') 
-#------------ Cell 2 --------------------
+```
+```python
 %%title
 # create a rich content title page
-#------------ Cell 3 --------------------
+```
+```python
 %%slide 1
 # slide 1 content
-#------------ Cell 4 --------------------
+```
+```python
 %%slide 1 -m # new in 1.4.6
-Markdown here with extended options. Nested blocks are not supported
-    ```multicol 30 70
-    less content
-    +++
-    more content
-    ```
-    ```python run source
-    x = 1 + 2
-    ls.write([x, source])
-    ```
-{{source}} will be shown in start here as well. Only variables are supported
-#------------ Cell 5 --------------------
+**Markdown here with extended options. Nested blocks are not supported**
+ ```multicol 30 70 .Success
+ less content
+ +++
+ more content
+ ```
+```
+**Markdown here with extended options. Nested blocks are not supported**
+```multicol 30 70 .Success
+less content
++++
+more content
+```
+```python run source
+x = 1 + 2
+print(x) # will be printed on slide in somehwewere top as print appears first of all. 
+# Use `with ls.capture_std() as std:  print();std.stdout` to see at exactly where it is printed.
+```
+There is a python block above with header `python run source`. We can display that block by  &lcub;&lcub;source&rcub;&rcub; as below:
+{{source}} 
+
+variable `x` defined there is shown here x = {{x}}. Only variables can be embeded in &lcub;&lcub;var&rcub;&rcub;, not expressions.
+```python
 @ls.frames(1,*objs)
 def func(obj):
     write(obj) #This will create as many slides after the slide number 1 as length(objs)
-#------------ Cell 6 --------------------
+```
+```python
 ls # This displays slides if on the last line of cell, or use `ls.show()`.
 ```
 
@@ -58,7 +73,7 @@ ls # This displays slides if on the last line of cell, or use `ls.show()`.
     - Slides are added in order of content.
     - Slides should be separated by `---` (three dashes) in start of line.
     - You can add more slides besides created ones or modify existing ones using `ls.md_content`:
-```python
+```python .monokai
 ls.from_markdown(path)
 with ls.slide(2):
     write(ls.md_content[2]) # write content of slide 2 from file
@@ -99,9 +114,11 @@ Having your cursor over slides, you can use follwoing keys/combinations:
 but captures of multiple times in a slides are first to last in order in time.
 
 ### PDF Printing
-There are two ways of printing to PDF.
-- Capturing each screenshot based on slide's state (in order) and later using `Save PDF`. This is a manual process but you have full control of view of slide.
-- Press `Print PDF` button and leave until it moves up to last slide and you will get single print per slide. If something don't load, increase `load_time` in `ls.print_settings` value and then print.
+- Capture screenshot of current state of slide by camera button in toolbar or by pressing `S` key. 
+    This will collect screenshots of current slide in order of capturing. 
+    This is a manual process but you can collect content as you want. You can hover top-right corner to use a slider to adjust height of visible content.
+- Press `Capture All` button in side panel to capture a single image of each slide. Then you can add images over it by manually capturing.
+- Press `Save PDF` button to save all screenshots as PDF.
 
 {how_to_slide[0]}
 
