@@ -6,10 +6,11 @@ and then provided to other classes via composition, not inheritance.
 import os 
 import datetime
 from IPython import get_ipython
-from IPython.display import display, Image
-from ..writers import write
+from IPython.display import display, Image, Javascript
+from IPython.utils.capture import capture_output
 from ..formatter import fix_ipy_image, code_css
-from ..utils import set_dir, html
+from ..extended_md import parse_xmd
+from ..utils import set_dir, html, details
 from . import scripts, intro, styles
 
 class LayoutSettings:
@@ -18,10 +19,11 @@ class LayoutSettings:
         self.widgets = _instanceWidgets
         self.animation = styles.animations['slide']
         self.font_scale = 1
-        self._font_family = {'code':'var(--jp-code-font-family)','text':'sans-serif'}
+        self._font_family = {'code':'var(--jp-code-font-family)','text':'STIXGeneral'}
         self._footer_text = 'IPySlides | <a style="color:skyblue;" href="https://github.com/massgh/ipyslides">github-link</a>'
         self._content_width = '90%' #Better
-        self._breakpoint_width = '650px'
+        self._breakpoint_width = f'{int(100*650/self.widgets.sliders.width.value)}px' # Whatever was set initially
+        self._code_lineno = True
         
         self.height_slider = self.widgets.sliders.height
         self.width_slider  = self.widgets.sliders.width
@@ -29,9 +31,6 @@ class LayoutSettings:
         self.theme_dd = self.widgets.ddowns.theme
         self.reflow_check = self.widgets.checks.reflow
         
-        self._instructions = self.widgets.outputs.intro
-        self.out_fixed = self.widgets.outputs.fixed
-        self.out_renew = self.widgets.outputs.renew
         self.btn_fs    = self.widgets.toggles.fscrn
         self.btn_zoom  = self.widgets.toggles.zoom
         self.btn_timer = self.widgets.toggles.timer
@@ -47,7 +46,7 @@ class LayoutSettings:
         self.reflow_check.observe(self._update_theme,names=['value'])
         self.sidebar_switch = self.widgets.toggles.display
         self.sidebar_switch.observe(self._toggle_sidebar,names=['value'])        
-        self.sidebar_switch.value = 0 # Initial Call must be inline, so that things should be shown outside Jupyterlab always
+        self.sidebar_switch.value = False # Initial Call must be inline, so that things should be shown outside Jupyterlab always
         
         self._update_theme() #Trigger Theme and Javascript in it
         self.set_code_style() #Trigger CSS in it, must
@@ -55,9 +54,12 @@ class LayoutSettings:
         
     def _on_displayed(self,change):
         self.__add_js()
-        self._instructions.clear_output(wait=True) # This make sure that instructions are not duplicated
-        with self._instructions:
-            write(intro.instructions)
+        
+        with capture_output() as cap:
+            parse_xmd(intro.instructions,display_inline=True)
+        # Only do this if it's in Jupyter, otherwise throws errors
+        self.widgets.htmls.intro.value = details('\n'.join(o.data['text/html'] for o in cap.outputs), summary="Instructions").value
+        self.widgets.htmls.intro.add_class('Intro')
             
     def set_animation(self,name):
         "Set animation style or pass None to disable animation."
@@ -68,9 +70,10 @@ class LayoutSettings:
         else:
             print(f'Animation {name!r} not found. Pass None or any of {list(styles.animations.keys())}.')
     
-    def set_code_style(self,style='default',background='var(--secondary-bg)'):
-        "Set code style CSS. Use background for better view of your choice."
-        self.widgets.htmls.hilite.value = code_css(style,background=background)
+    def set_code_style(self,style='default',color = None,background = None, accent_color = 'var(--tr-hover-bg)',lineno = True):
+        "Set code style CSS. Use background for better view of your choice. This is overwritten by theme change."
+        self._code_lineno = lineno # Used in theme to keep track 
+        self.widgets.htmls.hilite.value = code_css(style,color = color,background = background, lineno = lineno, accent_color = accent_color)
       
     def set_font_family(self,text_font=None,code_font=None):
         "Set main fonts for text and code."
@@ -80,7 +83,6 @@ class LayoutSettings:
             self._font_family['code'] = code_font  
         self._update_theme() # Changes Finally 
     
-
     def set_font_scale(self,font_scale=1):
         "Set font scale to increase or decrease text size. 1 is default."
         self.scale_slider.value = font_scale 
@@ -112,12 +114,6 @@ class LayoutSettings:
         
         self.widgets.htmls.footer.value = _text.replace('__number__',_number_str)
         
-    def code_lineno(self,b=True):
-        "Set code line numbers to be shown or not."
-        if b:
-            return display(html('style', 'code:before{ display:inline-block !important; }'))
-        return display(html('style', 'code:before{ display:none !important; }'))
-    
     def set_layout(self,center = True, content_width = None):
         "Central aligment of slide by default. If False, left-top aligned."
         self._content_width = content_width if content_width else self._content_width # user selected
@@ -133,13 +129,11 @@ class LayoutSettings:
         self._update_theme(change=None) # Trigger CSS in it to make width change
             
     def __add_js(self):
-        with self.out_fixed: 
-            display(scripts.navigation_js)
+        with self.widgets.outputs.fixed: 
+            display(Javascript(scripts.navigation_js))
     
     def _emit_resize_event(self):
-        with self.out_renew: 
-            self.out_renew.clear_output(wait=True)
-            display(scripts.resize_js)
+        self.widgets._exec_js(scripts.resize_js)
         
     def __update_size(self,change):
         self.widgets.mainbox.layout.height = '{}px'.format(self.height_slider.value)
@@ -161,17 +155,26 @@ class LayoutSettings:
         
     def _update_theme(self,change=None): 
         text_size = '{}px'.format(int(self.font_scale*16))
-        if self.theme_dd.value == 'Custom': # In case of Custom CSS
+        
+        if self.theme_dd.value != 'Custom':
+            theme_css =  styles.style_css(styles.theme_roots[self.theme_dd.value])
+        else: # In case of Custom CSS
             with set_dir(get_ipython().starting_dir):
                 if not os.path.isfile('custom.css'):
                     with open('custom.css','w') as f:
-                        f.write('/* Author: Abdul Saboor */\n' + styles.style_html( styles.theme_roots['Light']))
-                else: # Read CSS from file otherwise
-                    with open('custom.css','r') as f:
-                        theme_css = ''.join(f.readlines())
+                        f.write('/* Author: Abdul Saboor */\n' + styles.style_css( styles.theme_roots['Light']))
+                        
+                # Read CSS from file now
+                with open('custom.css','r') as f:
+                    theme_css = ''.join(f.readlines())
+        
+        if self.theme_dd.value == 'Dark':
+            self.set_code_style('monokai',color='#f8f8f2',lineno=self._code_lineno)
+        elif self.theme_dd.value == 'Fancy':
+            self.set_code_style('borland',lineno=self._code_lineno) 
         else:
-            theme_css =  styles.style_html(styles.theme_roots[self.theme_dd.value])
-            
+            self.set_code_style('default',lineno=self._code_lineno)
+               
         # Replace font-size and breakpoint size
         theme_css = theme_css.replace(
                         '__text_size__',text_size).replace(
@@ -192,13 +195,17 @@ class LayoutSettings:
     def _toggle_sidebar(self,change): 
         """Pushes this instance of LiveSlides to sidebar and back inline."""
         # Only push to sidebar if not in fullscreen
-        if self.btn_fs.value or self.sidebar_switch.value == 0:
+        if self.btn_fs.value or self.sidebar_switch.value == False:
+            self.widgets.mainbox.remove_class('SideMode')
             self.widgets.htmls.sidebar.value = '' # Should be empty to avoid competition of style
-            self.height_slider.layout.display = 'inline-flex' #Very impprtant
+            self.height_slider.layout.display = 'inline-flex' #Very important
+            self.sidebar_switch.description = '◨'
         else:
+            self.widgets.mainbox.add_class('SideMode')
             self.widgets.htmls.sidebar.value =  html('style',styles.sidebar_layout_css(span_percent=self.width_slider.value)).value
             self.height_slider.layout.display = 'none'
-
+            self.sidebar_switch.description = '▣'
+            
         return self._emit_resize_event() # Must return this event so it work in other functions.
     
     def _push_fullscreen(self,change):  
