@@ -4,16 +4,15 @@ and then provided to other classes via composition, not inheritance.
 """
 from dataclasses import dataclass
 import ipywidgets as ipw
-from ipywidgets import HTML, FloatProgress, VBox, HBox, Box, Layout, Button
+from IPython.display import display, Javascript
+from ipywidgets import HTML, FloatProgress, VBox, HBox, Box, GridBox, Layout, Button
 from . import styles
 from ..utils import html
 
 
 auto_layout =  Layout(width='auto')
-btns_layout = Layout(justify_content='space-around',padding='8px',height='max-content',min_height='30px',overflow='auto')
 def describe(value): 
     return {'description': value, 'description_width': 'initial','layout':Layout(width='auto')}
-
 @dataclass(frozen=True)
 class _Buttons:
     """
@@ -27,14 +26,14 @@ class _Buttons:
                 ).add_class('screenshot-btn') # .add_class('menu')
     pdf     = Button(description='Save PDF',layout= Layout(width='auto',height='auto'))
     png     = Button(description='Save PNG',layout= Layout(width='auto',height='auto'))
-    print   = Button(description='Print PDF',layout= Layout(width='auto',height='auto'))
+    cap_all = Button(description='Capture All',layout= Layout(width='auto',height='auto'))
     
 @dataclass(frozen=True)
 class _Toggles:
     """
     Instantiate under `Widgets` class only.
     """
-    display = ipw.ToggleButtons(description='Display Mode',options=[('Inline',0),('Sidebar',1)],value = 1).add_class('DisplaySwitch')
+    display = ipw.ToggleButton(description='◨', value = False, tooltip='Toggle ON/OFF Sidebar Mode').add_class('DisplaySwitch').add_class('voila-sidecar-hidden').add_class('menu')
     fscrn   = ipw.ToggleButton(description='Window',icon='expand',value = False).add_class('sidecar-only').add_class('window-fs')
     zoom    = ipw.ToggleButton(description='Zoom Items',icon='toggle-off',value = False).add_class('sidecar-only').add_class('mpl-zoom')
     timer   = ipw.ToggleButton(description='Timer',icon='play',value = False).add_class('sidecar-only').add_class('presenter-btn')             
@@ -46,7 +45,7 @@ class _Htmls:
     Instantiate under `Widgets` class only.
     """
     footer  = HTML('<p>Put Your Info Here using `self.set_footer` function</p>').add_class('Footer')
-    theme   = HTML(html('style',styles.style_html(styles.theme_roots['Fancy'].replace(
+    theme   = HTML(html('style',styles.style_css(styles.theme_roots['Fancy'].replace(
                 '__text_size__','16px')).replace(
                 '__breakpoint_width__','650px').replace(
                 '__textfont__','sans-serif').replace(
@@ -62,24 +61,25 @@ class _Htmls:
     hilite  = HTML() # Updated in settings on creation. For code blocks.
     fscrn   = HTML() # Full Screen CSS, do not add here!
     zoom    = HTML() # zoom-container CSS, do not add here!
+    capture = HTML('<span class="Info">Edit above box and hit Enter to see screenshot here. ' 
+                   'If nothing shown, your system does not support taking screenshots with PIL</span>').add_class('capture-html') # Screenshot image here
+    intro   = HTML().add_class('panel-text') # Intro HTML
 
 @dataclass(frozen=True)
 class _Inputs:
     """
     Instantiate under `Widgets` class only.
     """
-    bbox = ipw.Text(description='L,T,R,B (px)',layout=auto_layout,value='Type left,top,right,bottom pixel values and press ↲')
+    bbox = ipw.Text(description='L,T,R,B (px)',layout=auto_layout,value='Type left,top,right,bottom pixel values and press ↲').add_class('bbox-input')
 
 @dataclass(frozen=True)
 class _Checks:
     """
     Instantiate under `Widgets` class only.
     """
-    reflow = ipw.Checkbox(value=False,description='Reflow Code',layout=auto_layout)
-    notes  = ipw.Checkbox(value=False,description='Display Notes',layout=auto_layout) # do not observe, just keep track when slides work
-    toast  = ipw.Checkbox(value = False, description='Hide Notifications')
-        
-    
+    reflow = ipw.Checkbox(indent = False, value=False,description='Reflow Code',layout=auto_layout)
+    notes  = ipw.Checkbox(indent = False, value=False,description='Notes',layout=auto_layout) # do not observe, just keep track when slides work
+    toast  = ipw.Checkbox(indent = False, value = True, description='Notifications',layout=auto_layout)
 
 @dataclass(frozen=True)
 class _Sliders:
@@ -89,7 +89,7 @@ class _Sliders:
     progress = ipw.SelectionSlider(options=[('0',0)], value=0, continuous_update=False,readout=True)
     visible  = ipw.IntSlider(description='View (%)',min=0,value=100,max=100,orientation='vertical').add_class('float-control')
     height   = ipw.IntSlider(**describe('Height (px)'),min=200,max=2160, value = 400,continuous_update=False).add_class('height-slider') #2160 for 4K screens
-    width    = ipw.IntSlider(**describe('Width (vw)'),min=20,max=100, value = 50,continuous_update=False).add_class('width-slider')
+    width    = ipw.IntSlider(**describe('Width (vw)'),min=20,max=100, value = 40,continuous_update=False).add_class('width-slider') # 40 is best if something goes wrong, it can be pushed back
     scale    = ipw.FloatSlider(**describe('Font Scale'),min=0.5,max=3,step=0.0625, value = 1.0,readout_format='5.3f',continuous_update=False)
         
 
@@ -99,7 +99,7 @@ class _Dropdowns:
     Instantiate under `Widgets` class only.
     """
     theme = ipw.Dropdown(**describe('Theme'),options=[*styles.theme_roots.keys(),'Custom'],value='Inherit')
-    clear = ipw.Dropdown(description='Delete',options = ['None','Delete Current Slide Screenshots','Delete All Screenshots'])
+    clear = ipw.Dropdown(**describe('Delete'),options = ['None','Delete Current Slide Screenshots','Delete All Screenshots'])
         
     
 @dataclass(frozen=True)
@@ -109,7 +109,6 @@ class _Outputs:
     """
     slide = ipw.Output(layout= Layout(height='auto',margin='auto',overflow='auto',padding='2px 36px') # do not set width here, in css
             ).add_class('SlideArea')
-    intro = ipw.Output(clear_output=False, layout=Layout(width='100%',height='100%',overflow='auto',padding='4px')).add_class('panel-text')
     fixed = ipw.Output(layout=Layout(width='auto',height='0px')) # For fixed javascript
     renew = ipw.Output(layout=Layout(width='auto',height='0px')) # Content can be added dynamically
 
@@ -243,39 +242,34 @@ class Widgets:
         ]).add_class('NavWrapper')   #class is must
         
         self.panelbox = VBox([
-            Box([
-                self.outputs.intro,
-                self.buttons.setting,
-            ],layout=Layout(width='100%',height='auto',overflow='hidden')) ,
-            self.outputs.fixed, 
-            self.outputs.renew, # Must be in middle so that others dont get disturbed.
+            self.buttons.setting,
             VBox([
                 self.sliders.height.add_class('voila-sidecar-hidden'), 
                 self.sliders.width.add_class('voila-sidecar-hidden'),
                 self.sliders.scale,
                 self.ddowns.theme,
-                HTML('<hr/>'),
-                self.inputs.bbox,
-                ipw.HBox([
-                    self.checks.notes, 
-                    self.checks.toast, 
-                    self.checks.reflow
-                ],layout=btns_layout) ,
-                self.ddowns.clear,
-                HBox([
-                    self.buttons.png, 
-                    self.buttons.pdf, 
-                    self.buttons.print
-                ], layout=btns_layout) ,
-                HTML('<hr/>'),
-                HBox([
+                Box([GridBox([
                     self.toggles.fscrn,
-                    self.toggles.zoom, 
-                    self.toggles.timer
-                ], layout=btns_layout) ,
-            ],layout = Layout(width='100%',height='max-content',min_height='400px',overflow='auto'))
-        ],layout = Layout(width='70%',min_width='50%',height='100%',padding='4px',overflow='auto',display='none')
-        ).add_class('panel') 
+                     self.toggles.zoom,
+                    self.toggles.timer,
+                    self.checks.notes,
+                    self.checks.toast,
+                    self.checks.reflow,
+                    self.buttons.cap_all,
+                    self.buttons.pdf,
+                    self.buttons.png,
+                ],layout=Layout(width='auto',overflow_x='scroll',
+                                grid_template_columns='1fr 1fr 1fr',grid_gap='4px',
+                                padding='4px',margin='auto')
+                )],layout=Layout(min_height='120px')),# This ensures no collapse and scrollable Grid
+                self.ddowns.clear,
+                self.inputs.bbox,
+                self.htmls.capture,
+                self.outputs.fixed, 
+                self.outputs.renew,
+                self.htmls.intro  
+            ],layout=Layout(width='auto',height='auto',overflow_y='scroll',padding='8px',margin='0'))
+        ],layout = Layout(width='70%',min_width='50%',height='100%',overflow='hidden',display='none')).add_class('panel') 
         
         self.slidebox = Box([
             self.outputs.slide 
@@ -286,7 +280,8 @@ class Widgets:
             self.htmls.toast,
             self.htmls.main,
             self.htmls.theme,
-            self.htmls.logo, 
+            self.htmls.logo,
+            self.toggles.display, 
             self.htmls.sidebar,
             self.panelbox, 
             self.htmls.cursor,
@@ -311,4 +306,10 @@ class Widgets:
         "Send inside notifications for user to know whats happened on some button click. Set `title = None` if need only content. Remain invisible in screenshot."
         if content and isinstance(content,str):
             self.htmls.toast.value = '' # Set first to '', otherwise may not trigger for same value again.
-            self.htmls.toast.value = _notification(content=content,title=title,timeout=timeout)
\ No newline at end of file
+            self.htmls.toast.value = _notification(content=content,title=title,timeout=timeout)
+    
+    def _exec_js(self,code_string):
+        "Execute javascript code, output is not permanent."
+        self.outputs.renew.clear_output(wait = True)
+        with self.outputs.renew:
+            display(Javascript(code_string))
\ No newline at end of file
