@@ -5,7 +5,7 @@ from io import StringIO
 from IPython import get_ipython
 from .utils import textbox
 from .writers import write, iwrite
-from .formatter import libraries, plt2html, __reprs__
+from .formatter import libraries, __reprs__
 from ._base.intro import how_to_slide
 
 slides = get_ipython().user_ns['_s_l_i_d_e_s_'] # get slides from notebook instead of creating new one
@@ -21,26 +21,30 @@ fp = StringIO('\n'.join(how_to_slide) + '''\n---
 ```python run source
 import ipyslides as isd
 version = isd.__version__
+%xmd #### This is inline markdown parsed by magic {.Note .Warning}
 ```
-Version: {{version}} as executed from above code in markdown. 
+Version: {{version}} as executed from below code in markdown. 
+{{source}}
 ---
 # Slide 2 {.Success}
 Created using `%%slide 2 -m` with markdown only
 ```multicol
 # Column A
+||### Sub column A {.Success}||### Sub column B ||
 +++
 # Column B
 ```
 That version from last slide is still in memory. See it is there {{version}}
 ''')
-slides.from_markdown(fp) # This will create first slide along with title page.
+slides.from_markdown(fp, trusted=True) # This will create first slide along with title page.
 
 with slides.slide(1): #slide 1 will be modified with old and new content
-    with slides.source.context(style='monokai',background='black',className='Mono') as s:
-        write(slides.md_content[1])
+    with slides.source.context(style='monokai', color='white', className='Mono') as s:
+        slides.parse_xmd(slides.md_content[1])
+        #display(*get_ipython().user_ns['outputs'])
         write('## I am created using `with slides.slide(1)` context( manager!')
         write(f'I am {slides.alert("Alerted")} and I am *{slides.colored("colored and italic text","magenta","whitesmoke")}*')
-    write(s.focus_lines([0]))  #focus on line 0 
+    s.focus_lines([0]).display()  #focus on line 0 
     slides.notes.insert('### Note for slide 1')
     
 slides.shell.user_ns['write'] = write #Inject variable in IPython shell
@@ -64,7 +68,7 @@ def func(obj):
     with slides.source.context() as s:
         slides.write(obj)
         slides.notify_later()(lambda: 'That is a notification which shows you can use decorator this way as well')
-    write(s)
+    s.display()
 
 #Now generate many slides in a loop
 __contents = [f"""## IPython Display Objects
@@ -90,10 +94,10 @@ for i in range(4,8):
         write(__contents[i-4])
         if i == 7:
             with slides.source.context() as s:
-                write([slides.doc(write,'LiveSlides'), slides.doc(iwrite,'LiveSlides')])
-                write("#### If an object does not render as you want, use `display(object)` or it's own library's mehod to display inside Notebook.")
+                write([slides.doc(write,'LiveSlides'), slides.doc(iwrite,'LiveSlides'), slides.doc(slides.parse_xmd,'LiveSlides')])
+                write("#### If an object does not render as you want, use `display(object)` or register it as you want using `@LiveSlides.serializer.register` decorator")
             
-            write(s.show_lines([0,1]))
+            s.show_lines([0,1]).display()
 # Matplotlib
 with slides.slide(8,background='linear-gradient(to right, #FFDAB9 0%, #F0E68C 100%)'):
     write('## Plotting with Matplotlib')
@@ -109,7 +113,7 @@ with slides.slide(8,background='linear-gradient(to right, #FFDAB9 0%, #F0E68C 10
 # Youtube
 from IPython.display import YouTubeVideo
 with slides.slide(9):
-    with slides.source.context(style='vs',background='#FAA',className="Youtube") as s:
+    with slides.source.context(style='vs',className="Youtube") as s:
         write(f"### Watching Youtube Video?")
         write(YouTubeVideo('Z3iR551KgpI',width='100%',height='266px'))
         @slides.notify_later()
@@ -117,7 +121,7 @@ with slides.slide(9):
             t = time.localtime()
             return f'You are watching Youtube at Time-{t.tm_hour:02}:{t.tm_min:02}'
         
-        write(s) # source.context(style='vs',background='#FAA',className="Youtube")
+        s.display() # s = source.context(style='vs', className="Youtube")
     
 # Data Table
 with slides.slide(10):
@@ -130,7 +134,7 @@ with slides.slide(10):
             |d1|d2|d3|
             |r1|r2|r3|
             ''')))
-        write(s.focus_lines([3,4,5,6]))
+        s.focus_lines([3,4,5,6]).display()
 
 # Plotly and Pandas DataFrame only show if you have installed
 with slides.slide(11,background='#800000'):
@@ -154,12 +158,12 @@ with slides.slide(11,background='#800000'):
         write(('## Writing Pandas DataFrame',df),
             ('## Writing Altair Chart\nMay not work everywhere, needs javascript\n{.Note .Warning}',chart)
             )
-    write(slides.source.current.show_lines(range(5,12))) #Show source code of above block even without assignning to variable explicitly
+    slides.source.current.show_lines(range(5,12)).display() #Show source code of above block even without assignning to variable explicitly
     
 try:
     import plotly.graph_objects as go
     fig = go.Figure()
-    fig.add_trace(go.Bar([1,5,8,9]))
+    fig.add_trace(go.Bar(y=[1,5,8,9]))
 except:
     fig = '### Install `plotly` to view output'
 with slides.slide(12):
@@ -220,7 +224,7 @@ def func(obj):
                   s.show_lines([obj-14])
                   ],ax,width_percents=[40,60])
     if obj == 14:
-        slides.write(s.show_lines([5,6]))
+        s.show_lines([5,6]).display()
         
 # Frames structure
 boxes = [f'<div style="background:var(--tr-hover-bg);width:auto;height:auto;padding:8px;margin:8px;border-radius:4px;"><h1>{i}</h1></div>' for i in range(1,10)]
@@ -239,14 +243,14 @@ def f(obj):
     with slides.source.context() as s:
         slides.write('# Frames with \n#### `repeat = [(0,1,2),(3,4,5),(6,7,8)]`')
         slides.write(*obj)
-    slides.write(s)
+    s.display()
 
 with slides.slide(18):
     with slides.source.context() as s:
         slides.write(['## Displaying image from url from somewhere in Kashmir (کشمیر)',
                       slides.image(r'https://assets.gqindia.com/photos/616d2712c93aeaf2a32d61fe/master/pass/top-image%20(1).jpg')],
                      className='Success')
-    slides.write(s)
+    s.display()
 
 with slides.slide(19):
     slides.write('## $\LaTeX$ in Slides\nUse `$ $` or `$$ $$` to display latex in Markdown, or embed images of equations')
@@ -258,10 +262,31 @@ with slides.slide(19):
 with slides.slide(20):
     slides.write('## Built-in CSS styles')
     with slides.source.context() as s:
-        with slides.print_context():
-            slides.css_styles
-            
+        slides.css_styles.display()
         slides.write('Info',className='Info')
         slides.write('Warning',className='Warning')
         slides.write('سارے جہاں میں دھوم ہماری زباں کی ہے۔',className='Right RTL')
-    slides.write(s)
\ No newline at end of file
+    s.display()
+
+with slides.slide(21):
+    with slides.source.context() as s:
+        slides.rows(
+            '## Can skip `write` commnad sometimes',
+            slides.cols('### Column A','### Column B',className='Info'),
+            '||### Column C {.Warning}||### Column D {.Success}||',
+        ).display()
+        slides.image(r'https://assets.gqindia.com/photos/616d2712c93aeaf2a32d61fe/master/pass/top-image%20(1).jpg').display()
+    s.display()
+    
+with slides.slide(22):
+    slides.write('## Serialize Custom Objects to HTML\nThis is useful for displaying user defined/third party objects in slides')
+    with slides.capture_std():
+        with slides.source.context() as s:
+            @slides.serializer.register(int)
+            def colorize(obj):
+                color = 'red' if obj % 2 == 0 else 'green'
+                return f'<span style="color:{color};">{obj}</span>'
+
+            slides.write(*range(10))
+        
+        s.display()
\ No newline at end of file
