@@ -1,4 +1,4 @@
-import sys
+import sys, re
 from collections import namedtuple
 from contextlib import contextmanager, suppress
 
@@ -8,10 +8,10 @@ from IPython.display import display
 from IPython.utils.capture import capture_output
 import ipywidgets as ipw
 
-from .extended_md import parse_xmd
+from .extended_md import parse_xmd, _allowed_funcs
 from .source import Source
 from .writers import write, iwrite
-from .formatter import bokeh2html, plt2html, highlight
+from .formatter import bokeh2html, plt2html, highlight, _HTML, serializer
 from . import utils
 
 _under_slides = {k:getattr(utils,k,None) for k in utils.__all__}
@@ -28,11 +28,10 @@ except:
     sys.exit()
     
         
-class _PrivateSlidesClass(BaseLiveSlides):
-    """This is private class. Use `LiveSlides` instead."""
+class LiveSlides(BaseLiveSlides):
+    # This will be overwritten after creating a single object below!
+    __name__ = 'ipyslides.core.LiveSlides' # Used to validate code in markdown, must
     def __init__(self):
-        """This is private class. Use `LiveSlides` instead."""
-        # print(f'Inside: {self.__class__.__name__}')
         super().__init__() # start Base class in start
         self.shell = SHELL
         
@@ -46,10 +45,23 @@ class _PrivateSlidesClass(BaseLiveSlides):
         self.write  = write # Write IPython objects in slides
         self.iwrite = iwrite # Write Widgets/IPython in slides
         self.parse_xmd = parse_xmd # Parse extended markdown
+        self.serializer = serializer # Serialize IPython objects to HTML
+        
         with suppress(Exception): # Avoid error when using setuptools to install
             self.shell.register_magic_function(self.__slide, magic_kind='cell',magic_name='slide')
             self.shell.register_magic_function(self.__title, magic_kind='cell',magic_name='title')
+            self.shell.register_magic_function(self.notes.insert, magic_kind='line',magic_name='notes')
+            self.shell.register_magic_function(self.__xmd, magic_kind='line_cell',magic_name='xmd')
             self.user_ns = self.shell.user_ns #important for set_dir
+            
+            # Override print function to display in order in slides
+            def pprint(*args, **kwargs):
+                "Displays object(s) inline with others in corrct order. args and kwargs are passed to builtin print."
+                with self.capture_std() as std:
+                    print(*args, **kwargs)
+                std.stdout.display() # Display at the end
+            
+            self.shell.user_ns['pprint'] = pprint
         
         self._citations = {} # Initialize citations
         self.__slides_mode = True # Default is slides mode since it is more intuitive
@@ -69,8 +81,9 @@ class _PrivateSlidesClass(BaseLiveSlides):
         self.loading_html = self.widgets.htmls.loading #SVG Animation in it
         
         self.progress_slider = self.widgets.sliders.progress
+        self.progress_slider.label = '0' # Set inital value, otherwise it does not capture screenshot if title only
         self.progress_slider.observe(self.__update_content,names=['index'])
-        
+        self.markdown_callables = tuple(_allowed_funcs.split('|'))
         # All Box of Slides
         self._box =  self.widgets.mainbox
         self._box.on_displayed(self._on_displayed) 
@@ -83,19 +96,21 @@ class _PrivateSlidesClass(BaseLiveSlides):
             'You may enable it after that for fast loading of slides while presenting!').format(act = what_cannot_do))
     
     def _on_displayed(self, change):
-        with self.widgets.outputs.renew:
-            display(multi_slides_alert)
+        self.widgets._exec_js(multi_slides_alert)
         
         self._make_sure_title() # Should be before showing it below
         
         self.widgets.slidebox.children[0].clear_output(wait=True)
         with self.widgets.slidebox.children[0]: # title slide in both simple and computed case
             self.__slides_dict['0'].show() # Instead of refreshing, we can just update the content of the title slides to avoid errors
+        
+        with suppress(Exception): # Does not work everywhere.
+            self.widgets.inputs.bbox.value = ', '.join(str(a) for a in self.screenshot.screen_bbox) # Useful for knowing scren size
     
     def _make_sure_title(self):
         if '0' not in self.__slides_dict:
             with capture_output() as captured:
-                write(how_to_slide)
+                self.parse_xmd('\n'.join(how_to_slide), display_inline=True)
                 
             self.__slides_dict['0'] = captured
 
@@ -107,7 +122,11 @@ class _PrivateSlidesClass(BaseLiveSlides):
     
     @property
     def iterable(self):
-        return self.__iterable  
+        return self.__iterable 
+    
+    @property
+    def citations(self):
+        return self._citations 
     
     @property
     def _access_key(self):
@@ -123,20 +142,28 @@ class _PrivateSlidesClass(BaseLiveSlides):
         self._toasts = {'0':self._toasts.get('0',None) } # keep title page's toasts
         self.refresh() # Clear interface too
     
-    def cite(self,key, citation,here=False):
-        "Add citation in presentation, both key and citation are text/markdown/HTML."
+    def cite(self,key, citation = None,here = False):
+        "Add citation in presentation, key should be a unique string and citation is text/markdown/HTML."
         self._check_computed('add citations')
         if here:
             return utils.textbox(citation,left='initial',top='initial') # Just write here
-        self._citations[key] = citation
+        self._citations[key] =  citation or self.citations.get(key,None) # Get given first
         _id = list(self._citations.keys()).index(key)
-        return f'<sup style="color:var(--accent-color);">{_id + 1}</sup>'
+        # Return string otherwise will be on different place
+        return f'<a href="#{key}"><sup id ="{key}-back" style="color:var(--accent-color);">{_id + 1}</sup></a>'
     
-    def write_citations(self,title='### References'): 
+    def citations_html(self,title='### References'): 
         "Write all citations collected via `cite` method in the end of the presentation."    
-        collection = [f'<span><sup style="color:var(--accent-color);">{i+1}</sup>{v}</span>' for i,(k,v) in enumerate(self._citations.items())]
-        return write(title + '\n' +'\n'.join(collection))      
+        collection = [f'''<span id="{k}">
+            <a href="#{k}-back"><sup style="color:var(--accent-color);">{i+1}</sup></a>
+            {v if v else f"Set LiveSlides.citations[{k!r}] = 'citation value'"}
+            </span>''' for i,(k,v) in enumerate(self._citations.items())]
+        return _HTML(self.parse_xmd(title + '\n' +'<br/>'.join(collection), display_inline=False, rich_outputs = False))
     
+    def write_citations(self,title='### References'):
+        "Write all citations collected via `cite` method in the end of the presentation."
+        self.write(self.citations_html(title = title))
+        
     def show(self, fix_buttons = False): 
         "Display Slides. If icons do not show, try with `fix_buttons=True`."
         
@@ -152,10 +179,12 @@ class _PrivateSlidesClass(BaseLiveSlides):
             self.widgets.buttons.next.icon = 'chevron-right'
         
         return self._ipython_display_()
-
     
     def _ipython_display_(self):
         'Auto display when self is on last line of a cell'
+        if self.shell is None or self.shell.__class__.__name__ == 'TerminalInteractiveShell':
+            raise Exception('Python/IPython REPL cannot show slides. Use IPython notebook instead.')
+        
         if not self.__slides_mode:
             return print('Set "self.convert2slides(True)", then it will work.')
         
@@ -175,13 +204,10 @@ class _PrivateSlidesClass(BaseLiveSlides):
         except: pass # Do Nothing
          
         return ipw.VBox([
-                    ipw.HBox([
-                        ipw.HTML("""<b style='color:var(--accent-color);font-size:24px;'>IPySlides</b>"""),
-                        self.widgets.toggles.display
-                    ]),
+                    ipw.HTML("""<b style='color:var(--accent-color);font-size:24px;'>IPySlides</b>"""),
                     self.widgets.toggles.timer,
                     self.widgets.htmls.notes
-                ])
+                ]).add_class('ExtraControls')
     @property
     def _frameno(self):
         "Get current frame number, return 0 if not in frames in slide"
@@ -213,7 +239,7 @@ class _PrivateSlidesClass(BaseLiveSlides):
         self.loading_html.value = styles.loading_svg
         try:
             _slide_css = self._slides_css.get(self._access_key,'') 
-            if (self.print.is_printing == False) and (self._frameno < 2): # No animations while printing or frames
+            if (self.screenshot.capturing == False) and (self._frameno < 2): # No animations while printing or frames
                 _slide_css += self.settings.animation # Animation style
             
             self.widgets.outputs.slide.clear_output(wait=True)
@@ -225,7 +251,7 @@ class _PrivateSlidesClass(BaseLiveSlides):
            
     def __switch_slide(self,old_index, new_index): # this change is provide from __update_content
         slide_css = self._slides_css.get(self._access_key,'') # Get CSS
-        if (self.print.is_printing == False) and (self._frameno < 2): # No animations while printing or frames
+        if (self.screenshot.capturing == False) and (self._frameno < 2): # No animations while printing or frames
             slide_css += self.settings.animation
              
         self.widgets.slidebox.children[-1].clear_output(wait=False) # Clear last slide CSS
@@ -310,20 +336,31 @@ class _PrivateSlidesClass(BaseLiveSlides):
             %%slide 1                             
             #python code here                     
         
-        You can use another cell magic under it to capture cell content as you want, e.g.
+        You can use extended markdown to create slides
             ---------------- Cell ----------------
-            %%slide 2
-            %%markdown
+            %%slide 2 -m
             Everything here and below is treated as markdown, not python code.
+            (1.5.5+) If Markdown is separated by three underscores (___) on it's own line, multiple frames are created.
+            Markdown before the first three underscores is written on all frames. This is equivalent to `@LiveSlides.frames` decorator.
         """
         line = line.strip().split() #VSCode bug to inclue \r in line
         if line and not line[0].isnumeric():
             raise ValueError(f'You should use %%slide integer >= 1 -m(optional), got {line}')
         
-        with self.slide(int(line[0])):
-            if '-m' in line[1:]:
-                parse_xmd(cell, display_inline = True)
+        slide_number = int(line[0])
+        
+        if '-m' in line[1:]:
+            _frames = re.split(r'^___$|^___\s+$',cell,flags = re.MULTILINE) # Split on --- or ---\s+
+            if len(_frames) == 1:
+                with self.slide(slide_number):
+                    parse_xmd(cell, display_inline = True, rich_outputs = False)
             else:
+                @self.frames(slide_number, *_frames[1:])
+                def create_frames(obj):
+                    parse_xmd(_frames[0], display_inline = True, rich_outputs = False) # This goes with every frame
+                    parse_xmd(obj, display_inline = True, rich_outputs = False)
+        else:
+            with self.slide(slide_number):
                 self.shell.run_cell(cell)
     
     @contextmanager
@@ -341,7 +378,7 @@ class _PrivateSlidesClass(BaseLiveSlides):
         self._current_slide = f'{slide_number}'
         with capture_output() as cap:
             self.__insert_slide_css(**css_props)
-            yield
+            yield cap # Useful to use later
         # Now Handle What is captured
         if not self.__slides_mode:
             cap.show()
@@ -355,16 +392,27 @@ class _PrivateSlidesClass(BaseLiveSlides):
         "Turns to cell magic `title` to capture title"
         with self.slide(0):
             if '-m' in line:
-                parse_xmd(cell, display_inline = True)
+                parse_xmd(cell, display_inline = True, rich_outputs = False)
             else:
                 self.shell.run_cell(cell)
+    
+    def __xmd(self, line, cell = None):
+        """Turns to cell magics `%%xmd` and line magic `%xmd` to display extended markdown. 
+        Can use in place of `write` commnad for strings.
+        When using `%xmd`, variables should be `{{{{var}}}}` or `\{\{var\}\}`, not `{{var}}` as IPython 
+        does some formatting to line in magic. If you just need to format it in string, then `{var}` works as well.
+        Inline columns are supported with ||C1||C2|| syntax."""
+        if cell is None:
+            return parse_xmd(line, display_inline = True, rich_outputs = False)
+        else:
+            return parse_xmd(cell, display_inline = True, rich_outputs = False)
             
     @contextmanager
     def title(self,**css_props):
         """Use this context manager to write title.
         `css_props` are applied to current slide. `-` -> `_` as `font-size` -> `font_size` in python."""
-        with self.slide(0, **css_props):
-            yield
+        with self.slide(0, **css_props) as s:
+            yield s # Useful to use later
     
     def frames(self, slide_number, *objs, repeat = False, frame_height = 'auto', **css_props):
         """Decorator for inserting frames on slide, define a function with one argument acting on each obj in objs.
@@ -458,7 +506,9 @@ class _PrivateSlidesClass(BaseLiveSlides):
         return tuple(slides_iterable)
 
 # Make available as Singleton LiveSlides
-_private_instance = _PrivateSlidesClass() # Singleton in use namespace
+_private_instance = LiveSlides() # Singleton in use namespace
+# This is overwritten below to just have a singleton
+
 class LiveSlides:
     """Interactive Slides in IPython Notebook. Only one instance can exist. 
     
@@ -472,13 +522,20 @@ class LiveSlides:
     
     Instead of builtin `print` in slides use following to display printed content in correct order.
     ```python
-    with ls.print_context():
+    with ls.capture_std() as std:
         print('something')
         function_that_prints_something()
+        display('Something') # Will be displayed here
+        ls.write(std.stdout) # Will be written here whatever printed above this line
+        
+    std.stdout.display() #ls.write(std.stdout)
     ```
-    
+    In version 1.5.9+ function `pprint` is avalible in IPython namespace when LiveSlide is initialized. This displays objects in intended from rather than just text.
     > `ls.demo` and `ls.from_markdown` overwrite all previous slides.
     
+    Aynthing with class name 'report-only' will not be displayed on slides, but appears in document when `ls.export.report` is called.
+    This is useful to fill-in content in document that is not required in slides.
+    
     > All arguments are passed to corresponding methods in `ls.settings`, so you can use those methods to change settings as well.
     """
     def __new__(cls,
@@ -495,15 +552,16 @@ class LiveSlides:
                 code_lineno   = True, 
                 animation     = 'slide_h'):
         "Returns Same instance each time after applying given settings. Encapsulation."
+        _private_instance.__doc__ = cls.__doc__ # copy docstring
         _private_instance.settings.set_layout(center = center, content_width = content_width)
         _private_instance.settings.set_footer(text = footer_text, show_date = show_date, show_slideno = show_slideno)
         _private_instance.settings.set_logo(src = logo_src)
         _private_instance.settings.set_font_scale(font_scale = font_scale)
         _private_instance.settings.set_font_family(text_font = text_font, code_font = code_font)
-        _private_instance.settings.set_code_style(style = code_style)
-        _private_instance.settings.code_lineno(b = code_lineno)
+        _private_instance.settings.set_code_style(style = code_style, lineno = code_lineno)
         _private_instance.settings.set_animation(name = animation)
         return _private_instance
     
     # No need to define __init__, __new__ is enough to show signature and docs
     
+    
