@@ -8,7 +8,7 @@ from io import BytesIO
 import matplotlib.pyplot as plt
 import pygments
 import ipywidgets as ipw
-from IPython.display import HTML 
+from IPython.display import display, HTML 
 from IPython.core.display import __all__ as _all
 from IPython import get_ipython
 
@@ -33,6 +33,10 @@ class _HTML(HTML):
         elif isinstance(other,str):
             return _HTML(self._repr_html_() + other)
     
+    def display(self):
+        "Display this HTML object inline"
+        display(self)
+    
     @property
     def value(self):
         "Returns HTML string."
@@ -61,6 +65,10 @@ class _HTML_Widget(ipw.HTML):
             return _HTML(self._repr_html_() + other._repr_html_())
         elif isinstance(other,str):
             return _HTML(self._repr_html_() + other)
+    
+    def display(self):
+        "Display this HTML widget inline"
+        display(self)
 
 
 def plt2html(plt_fig=None,transparent=True,caption=None):
@@ -109,28 +117,62 @@ def _ipy_imagestr(image,width='100%'):
     return fix_ipy_image(image,width=width).value
 
 
-def code_css(style='default',background='var(--secondary-bg)',className = None):
-    "Style code block with given style from pygments module and background color."
+def code_css(style='default',color = None, background = None, accent_color = 'var(--tr-hover-bg)', className = None, lineno = True):
+    """Style code block with given style from pygments module. `color` and `background` are optional and will be overriden if pygments style provides them.
+    """
     if style not in pygments.styles.get_all_styles():
         raise ValueError(f"Style {style!r} not found in {list(pygments.styles.get_all_styles())}")
     _class = '.highlight' if className is None else f'.highlight.{className}'
-    _style = pygments.formatters.HtmlFormatter(style=style).get_style_defs(_class)
-
+    _style = pygments.formatters.HtmlFormatter(style = style).get_style_defs(_class)
+    if style == 'default':
+        _bg_fg = {'background': 'var(--secondary-bg)', 'color': 'var(--primary-fg)'} # Should match inherit theme
+    else: # Override color and background if provided by theme
+        _bg_fg = {} 
+        items = [b.strip().split() for b in ''.join(re.findall(f'{_class}\s+?{{(.*?)}}',_style)).replace(':',' ').rstrip(';').split(';')]
+        for item in items:
+            if len(item) == 2 and item[0] in ('background','color'):
+                _bg_fg[item[0]] = item[1]      
+    
+    # keep user preferences               
+    bg = background if background else _bg_fg.get('background','var(--secondary-bg)')
+    fg = color if color else _bg_fg.get('color','var(--primary-fg)')
+    
+    gradient = f'linear-gradient(to right, {accent_color}, {accent_color} 2.2em, {bg} 2.2em, {bg} 100%)'
+        
     return f"""<style>\n{_style}
-    div{_class} pre, div{_class} code:before {{
-        background: {background} !important;
+    {_class} {{ 
+        background: {gradient if lineno else bg}; 
+        color: {fg}; 
+        border-left: 2px solid {accent_color};
     }}
-    div{_class} code:hover::before {{
-        background: none !important;
+    span.err {{border: none !important;}}
+    
+    {_class} code {{
+        padding-left: {'2.2em' if lineno else '0.5em'};
+    }}
+    {_class} code:hover {{
+        background: {accent_color} !important; /* Important to override default hover */
+    }}
+    {_class} code:before {{
+        opacity: 0.95;
+        background: {accent_color};
+        width: {'1.2em' if lineno else '0'};
+        color: {fg};
+        display:{'inline-block' if lineno else 'none'} !important;
     }}\n</style>"""
 
-def highlight(code, language='python', name = None, className = None, style='default', background = 'var(--secondary-bg)'):
+def highlight(code, language='python', name = None, className = None, style='default', color = None, background = None, accent_color = 'var(--tr-hover-bg)', lineno = True):
     """Highlight code with given language and style. style only works if className is given.
+    If className is given and matches any of pygments.styles.get_all_styles(), then style will be applied immediately.
+    color is used for text color as some themes dont provide text color.
     New in version 1.4.3"""
     if style not in pygments.styles.get_all_styles():
         raise ValueError(f"Style {style!r} not found in {list(pygments.styles.get_all_styles())}")
+    if className in pygments.styles.get_all_styles():
+        style = className
+        
     formatter = pygments.formatters.HtmlFormatter(style = style)
-    _style = code_css(style=style, background = background, className=className) if className else ''
+    _style = code_css(style=style, color = color, background = background, accent_color = accent_color,className=className, lineno = lineno) if className else ''
     _code = pygments.highlight(textwrap.dedent(code), # dedent make sure code blocks at any level are picked as well
                                pygments.lexers.get_lexer_by_name(language),
                                formatter)
@@ -150,6 +192,70 @@ def highlight(code, language='python', name = None, className = None, style='def
         <pre>{code_}
         </pre>\n{end}</div>''')
     
+class RegisterSerializer:
+    def __init__(self):
+        """Register serializer for an object to use inside LiveSlides.write/iwrite."""
+        self._libs = []
+    
+    def register(self, obj_type, verbose = True):
+        """Decorator to register html serializer for an object type. 
+        Decoracted function accepts one argument that will take `obj_type` and should return html string.
+        This definition will take precedence over any other in the module.
+        All regeisted serializers only exist for the lifetime of the module in a namespace.
+        Only a single serializer can be registered for an object type.
+        
+        **Usage**
+        ```python
+        class MyObject:
+            def __repr__(self):
+                return 'My object is awesome'
+        
+        ls = ipyslides.LiveSlides()
+        @ls.serializer.register(MyObject)
+        def parse_myobject(obj):
+            return f'<h1>{obj!r}</h1>'
+            
+        my_object = MyObject()
+        ls.write(my_object) #This will write "My object is awesome" as main heading
+        parse_myobject(my_object) #This will return "<h1>My object is awesome</h1>"
+        ```
+        
+        **Note**: Serializer function should return html string. It is not validated for correct code on registration time.
+        """
+        def _register(func):
+            if obj_type is str:
+                raise TypeError("Cannot register serializer for string type! Use custom class to encapsulate string the way you want.")
+            item = {'obj': obj_type, 'func': func}
+            already = False
+            for i, _lib in enumerate(self._libs):
+                if item['obj'] is _lib['obj']:
+                    self._libs[i] = item
+                    if verbose:
+                        print(f'Updated: {item["obj"]} → {item["func"].__name__}({item["obj"]})')
+                    already = True
+                    break
+                    
+            if not already:
+                self._libs.append(item)
+                if verbose:
+                    print(f'Registered: {item["obj"]} → {item["func"].__name__}({item["obj"]})')
+                
+            return func
+        return _register
+    
+    def unregister(self, obj_type):
+        "Unregister all serializer handlers for a type."
+        for item in self._libs:
+            if obj_type is item['obj']:
+                self._libs.remove(item)
+    
+    def __repr__(self):
+        return 'Serializer(\n\t' + '\n\t'.join(f'{item["obj"]} → {item["func"].__name__}({item["obj"]})' for item in self._libs) + '\n)'
+
+serializer = RegisterSerializer()
+del RegisterSerializer # Make sure this is not used by user
+
+    
 # ONLY ADD LIBRARIEs who's required objects either do not have a _repr_html_ method or need ovverride
 
 libraries = [
@@ -164,14 +270,20 @@ libraries = [
 
 def format_object(obj):
     "Returns string of HTML for given object."
+    for _lib in serializer._libs:
+        if isinstance(obj, _lib['obj']):
+            return True, _lib['func'](obj)
+    
     # If matplotlib axes given, handle it separately
     if hasattr(obj,'get_figure'): 
         return True,_plt2htmlstr(obj.get_figure())
     
     # Some builtin types
     if isinstance(obj,dict):
-        return  True, f"<div class='PyRepr'>{json.dumps(obj,indent=4)}</div>"    
-    elif isinstance(obj,(set,list,tuple,int,float)): # Then prefer other builtins
+        return  True, f"<div class='PyRepr'>{json.dumps(obj,indent=4)}</div>"  
+    elif isinstance(obj,(int,float, bool)):
+        return True, str(obj)  
+    elif isinstance(obj,(set,list,tuple)): # Then prefer other builtins
         return True, f"<div class='PyRepr'>{obj}</div>"
     
     # If Code object given
