@@ -1,5 +1,5 @@
-__all__ = ['print_context',  'details', 'plt2html', 'set_dir', 'textbox', 'vspace',
-            'image','svg','format_html','format_css','alert','colored','keep_format',
+__all__ = ['capture_std', 'details', 'set_dir', 'textbox', 'vspace',
+            'image','svg','iframe', 'format_html','format_css','alert','colored','keep_format',
             'raw','enable_zoom','html','sig','doc']
 __all__.extend(['rows','cols','block'])
 __all__.extend([f'block_{c}' for c in 'rgbycmkowp'])
@@ -8,25 +8,54 @@ __all__.extend([f'block_{c}' for c in 'rgbycmkowp'])
 import os
 import inspect
 from io import BytesIO # For PIL image
-from contextlib import contextmanager
+from contextlib import contextmanager, suppress
 
-from IPython.display import SVG
+from IPython.display import SVG, IFrame, display
 from IPython.utils.capture import capture_output
 from IPython.core.display import Image
 import ipywidgets as ipw
 
 from .formatter import fix_ipy_image, _HTML
-from .writers import write, _fmt_write, _fix_repr
+from .writers import _fmt_write, _fix_repr
  
-        
+class CapturedStd:
+    "Not reuqired by user, so will be deleted"
+    def __init__(self):
+        self._captured = None
+    @property
+    def stdout(self):
+        return raw(self._captured.stdout)
+    @property
+    def stderr(self):
+        return alert(self._captured.stderr)
+    
+    def __repr__(self):
+        _out = f'{self._captured.stdout[:10]}...' if len(self._captured.stdout) > 10 else self._captured.stdout
+        _err = f'{self._captured.stderr[:10]}...' if len(self._captured.stderr) > 10 else self._captured.stderr
+        return f'CapturedStd(stdout = {_out!r}, stderr = {_err!r})'
+    
+_captured_std = CapturedStd()
+del CapturedStd # No need outside of this module
+    
 @contextmanager
-def print_context():
-    "Use `print` or function printing with onside in this context manager to display in order."
-    with capture_output() as cap:
-        yield
-    if cap.stderr:
-        return cap.stderr
-    write(raw(cap.stdout)) # clean whitspace preserved 
+def capture_std(): 
+    """Context manager to capture stdout and stderr, displays all other rich objects inline.
+    
+    **Usage**
+    ```python
+    with capture_std() as std:
+        print('Hello')
+        display('World')
+    # 'World' will be displayed inline, but 'Hello' will be captured
+    std.stdout # yields `raw('Hello')`
+    std.stderr # yields `alert('')`
+    ```
+    """    
+    with capture_output() as cap: 
+        _captured_std._captured = cap # Store output
+        yield _captured_std # Return the std as function to get later.
+    
+    return display(*cap.outputs) # Display outputs after context manager is exited.
     
 @contextmanager
 def set_dir(path):
@@ -58,7 +87,7 @@ def __check_pil_image(data):
     "Check if data is a PIL Image or numpy array"
     if data.__repr__().startswith('<PIL'):
         im_bytes = BytesIO()
-        data.save(im_bytes,data.format,quality=95) #Save image to BytesIO in format of given image
+        data.save(im_bytes,data.format if data.format else 'PNG',quality=95) #Save image to BytesIO in format of given image
         return im_bytes.getvalue()
     return data # if not return back data
 
@@ -90,6 +119,11 @@ def svg(data=None,caption=None,zoomable=True,**kwargs):
         return _HTML(f'<div class="zoom-container">{svg}</div>')
     return _HTML(svg)
 
+def iframe(src, width='100%',height='auto',**kwargs):
+    "Display `src` in an `iframe`. `kwrags` are passed to IPython.display.IFrame"
+    f = IFrame(src,width,height, **kwargs)
+    return _HTML(f._repr_html_())
+
 def enable_zoom(obj):
     "Add zoom-container class to given object, whether a widget or html/IPYthon object"
     try:
@@ -102,7 +136,7 @@ def html(tag, children = None,className = None,**node_attrs):
     `tag` can be any valid html tag name.
     `children` expects:
     
-    - If None, returns self closing html node such as <img...></img>.
+    - If None, returns self closing html node such as <img alt='Image'></img>.
     - str: A string to be added as node's text content.
     - list/tuple of [objects]: A list of objects that will be parsed and added as child nodes. Widgets are not supported.
     
@@ -153,9 +187,10 @@ def keep_format(plaintext_or_html):
         return plaintext_or_html # if not string, return as is
     return _HTML(plaintext_or_html) 
 
-def raw(text):
+def raw(text, className=None):
     "Keep shape of text as it is, preserving whitespaces as well."
-    return _HTML(f"<div class='PyRepr'>{text}</div>")
+    _class = className if className else ''
+    return _HTML(f"<div class='PyRepr {_class}'>{text}</div>")
 
 def rows(*objs, className=None):
     "Returns tuple of objects. Use in `write`, `iwrite` for better readiability of writing rows in a column."
@@ -212,17 +247,65 @@ def sig(callable,prepend_str = None):
     try:
         _sig = f'<b>{callable.__name__}</b><span style="font-size:85%;color:var(--secondary-fg);">{str(inspect.signature(callable))}</span>'
         if prepend_str: 
-            _sig = f'{alert(prepend_str)}.{_sig}' # must be inside format string
+            _sig = f'{colored(prepend_str,"var(--accent-color)")}.{_sig}' # must be inside format string
         return _HTML(_sig)
     except:
         raise TypeError(f'Object {callable} is not a callable')
 
-def doc(callable,prepend_str = None):
-    "Returns documentation of a callable. You can prepend a class/module name."
-    try:
-        _doc = _fix_repr(inspect.getdoc(callable))
-        _sig = sig(callable,prepend_str)
-        return _HTML(f"<div class='Docs'>{_sig}<br>{_doc}\n</div>")
-    except:
-        raise TypeError(f'Object {callable} is not a callable')
-    
\ No newline at end of file
+
+def doc(obj,prepend_str = None, members=None):
+    "Returns documentation of an `obj`. You can prepend a class/module name. members is True/List of attributes to show doc of."
+    if obj is None:
+        return _HTML('') # Must be _HTML to work on memebers
+    
+    _doc, _sig, _full_doc = '', '', ''
+    with suppress(BaseException): # if not __doc__, go forwards
+        _doc += _fix_repr((inspect.getdoc(obj) or '').replace('{','\u2774').replace('}','\u2775'))
+    
+    with suppress(BaseException): # This allows to get docs of module without signature
+        _sig = sig(obj,prepend_str)
+    
+    # If above fails, try to get name of module/object
+    _name = obj.__name__ if hasattr(obj,'__name__') else type(obj).__name__
+    if _name == 'property':
+        _name = obj.fget.__name__
+        
+    _pstr = f'{str(prepend_str) + "." if prepend_str else ""}{_name}'
+    
+    if _name.startswith('_'): # Remove private attributes
+        return _HTML('') # Must be _HTML to work on memebers
+    
+    _sig = _sig or colored(_pstr,"var(--accent-color)") # Picks previous signature if exists
+    _full_doc = f"<div class='Docs'>{_sig}<br>{_doc}\n</div>"
+    
+    _mems = []
+    if members == True:
+        if hasattr(obj,'__all__'):
+            _mems = [getattr(obj, a, None) for a in obj.__all__]
+        else: # if no __all__, show all public members
+            for attr in [getattr(obj, d) for d in dir(obj) if not d.startswith('_')]:
+                if inspect.ismodule(obj): # Restrict imported items in docs
+                    if hasattr(attr, '__module__')  and attr.__module__ == obj.__name__:
+                        _mems.append(attr) 
+                elif inspect.isclass(obj):
+                    if inspect.ismethod(attr) or inspect.isfunction(attr) or type(attr).__name__ == 'property':
+                        _mems.append(attr)
+                else:
+                    with suppress(BaseException):
+                        if attr.__module__ == obj.__module__: # Most useful
+                            _mems.append(attr)
+                
+    elif isinstance(members, (list, tuple, set)):
+        for attr in members:
+            if not hasattr(obj,attr):
+                raise AttributeError(f'Object {obj} does not have attribute {attr!r}')
+            else:
+                _mems.append(getattr(obj,attr))
+    
+    # Collect docs of members
+    for attr in _mems:
+        with suppress(BaseException):
+            _class_members = inspect.ismodule(obj) and inspect.isclass(attr)
+            _full_doc += doc(attr, prepend_str=f'{_pstr}',members = _class_members).value
+    
+    return _HTML(_full_doc)
\ No newline at end of file
